/* $Workfile: OtxBurst.h $   $Revision: 1 $    $Modtime: 2/10/03 11:33a $  */
#ifndef OTX_BURST_H
#define OTX_BURST_H
/*******************************************************************************

  @doc PublicHwApi OtxBurst

  Copyright (C) 2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxBurst | Prototypes for the Logical DMA Burst Device (Sender/Receiver) Functions

  @contents2
  OtxBurst.h |

  @index func | OtxBurst

  @contents2
  OTX Logical DMA Burst Sender/Receiver Functions - OtxBurstXXX() | The API functions for the Logical DMA Burst device

  @head3 OtxBurstXXX() Function Reference |

  @index func | OtxBurst

*******************************************************************************/

#ifdef __cplusplus
  extern "C" {
#endif

#include "OtxType.h"
#include "OtxDef.h"

#define OTXBURST_SDK_EVENT_BUF_LEN    0x0320   // Length of the Circular buffer (in words)
#define OTXBURST_SDK_MASK_HANDLE      0x00FF

/*******************************************************************************

  @func
    Configure the Burst Device.

  @comm
    Configure the DMA Burst operation by calling the function <f OtxDrvEnable> and stop
    it by calling the function <f OtxDrvDisable>

  @xref
    <f OtxBurstReceiverInit>
    <nl><t OtxBurstFrameFillTypeE>
    <nl><t OtxBurstCrcModeE>
    <nl><t OtxBurstTxRateE>

*******************************************************************************/
OTX_RESULT OtxBurstConfigure(
  IN OTX_HANDLE   hBurstDevice,               // @parm Handle to logical Burst Device
  IN void         *pBuffer,                   // @parm DMA buffer
  IN OTX_UINT32   nBufferSize                 // @parm DMA buffer size
);


#ifdef __cplusplus
  } // extern "C"
#endif


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif // OTX_BURST_H
